@@ -18,6 +18,8 @@
 # Free Software Foundation, Inc., Franklin Street, Fifth Floor,
 # Boston MA  02110-1301 USA.
 
+# pylint: disable=too-many-lines
+
 """Labels for Orca's GUIs. These have been put in their own module so that we
 can present them in the correct language when users change the language on the
 fly without having to reload a bunch of modules."""
@@ -29,7 +31,7 @@ __copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc." \
                 "Copyright (c) 2010-2013 The Orca Team"
 __license__   = "LGPL"
 
-from .orca_i18n import _, C_
+from .orca_i18n import _, C_, ngettext # pylint: disable=import-error
 
 # Translators: This string appears on a button in a dialog. "Activating" the
 # selected item will perform the action that one would expect to occur if the
@@ -75,8 +77,23 @@ AUTO_FOCUS_MODE_STRUCT_NAV = _("Automatic focus mode during structural navigatio
 # of the entry.
 AUTO_FOCUS_MODE_CARET_NAV = _("Automatic focus mode during caret navigation")
 
+# Translators: Orca has a number of commands that override the default behavior
+# within an application. For instance, if you are at the bottom of an entry and
+# press Down arrow, should you leave the entry? It depends on if you want to
+# resume reading content or if you are editing the text in the entry. Because
+# Orca doesn't know what you want to do, it has two modes: In browse mode, Orca
+# treats key presses as commands to read the content; in focus mode, Orca treats
+# key presses as something that should be handled by the focused widget. Orca
+# optionally can attempt to detect which mode is appropriate for the current
+# situation and switch automatically. This string is a label for a GUI option to
+# enable such automatic switching when native navigation commands are used.
+# Here "native" means "not Orca"; it could be a browser navigation command such
+# as the Tab key, or it might be a web page behavior, such as the search field
+# automatically gaining focus when the page loads.
+AUTO_FOCUS_MODE_NATIVE_NAV = _("Automatic focus mode during native navigation")
+
 # Translators: A single braille cell on a refreshable braille display consists
-# of 8 dots. Dot 7 is the dot in the bottom left corner. If the user selects 
+# of 8 dots. Dot 7 is the dot in the bottom left corner. If the user selects
 # this option, Dot 7 will be used to 'underline' text of interest, e.g. when
 # "marking"/indicating that a given word is bold.
 BRAILLE_DOT_7 = _("Dot _7")
@@ -217,12 +234,68 @@ ECHO_CHARACTER = _("Enable echo by cha_racter")
 # enabled, dead keys will be announced when pressed.
 ECHO_DIACRITICAL = _("Enable non-spacing _diacritical keys")
 
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This string is the title
+# of the dialog box.
+FIND_DIALOG_TITLE = _("Find")
+KB_GROUP_FIND = FIND_DIALOG_TITLE
+
 # Translators: Orca has a "find" feature which allows the user to search the
 # active application for on screen text and widgets. This label is associated
-# with the setting to begin the search from the current location rather than
-# from the top of the screen.
+# with the text entry where the user types the term to search for.
+FIND_SEARCH_FOR = _("_Search for:")
+
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This label is associated
+# with a group of options related to where the search should begin. The options
+# are to begin the search from the current location or from the top of the window.
+FIND_START_FROM = _("Start from:")
+
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This label is associated
+# with the radio button to begin the search from the current location rather
+# than from the top of the window.
 FIND_START_AT_CURRENT_LOCATION = _("C_urrent location")
 
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This label is associated
+# with the radio button to begin the search from the top of the window rather
+# than the current location.
+FIND_START_AT_TOP_OF_WINDOW = _("_Top of window")
+
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This label is associated
+# with a group of options related to the direction of the search. The options
+# are to search backwards and to wrap.
+FIND_SEARCH_DIRECTION = _("Search direction:")
+
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This label is associated
+# with the checkbox to perform the search in the reverse direction.
+FIND_SEARCH_BACKWARDS = _("Search _backwards")
+
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This label is associated
+# with the checkbox to wrap around when the top/bottom of the window has been
+# reached.
+FIND_WRAP_AROUND = _("_Wrap around")
+
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This label is associated
+# with a group of options related to what constitutes a match. The options are
+# to match case and to match the entire word only.
+FIND_MATCH_OPTIONS = _("Match options:")
+
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This label is associated
+# with the checkbox to make the search case-sensitive.
+FIND_MATCH_CASE = _("_Match case")
+
+# Translators: Orca has a "find" feature which allows the user to search the
+# active application for on screen text and widgets. This label is associated
+# with the checkbox to only match if the full word consists of the search term.
+FIND_MATCH_ENTIRE_WORD = _("Match _entire word only")
+
 # Translators: This is the label for a spinbutton. This option allows the user
 # to specify the number of matched characters that must be present before Orca
 # speaks the line that contains the results from an application's Find toolbar.
@@ -259,6 +332,21 @@ KB_HEADER_KEY_BINDING = _("Key Binding")
 # to, for instance, web browsing.
 KB_GROUP_DEFAULT = C_("keybindings", "Default")
 
+# Translators: This string is a label for the group of Orca commands which
+# are related to debugging.
+KB_GROUP_DEBUGGING_TOOLS = C_("keybindings", "Debugging Tools")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to its "learn mode". Please use the same translation as done
+# in cmdnames.py
+KB_GROUP_LEARN_MODE = C_("keybindings", "Learn mode")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to presenting and performing the accessible actions associated
+# with the current object.
+KB_GROUP_ACTIONS = _("Actions")
+ACTIONS_LIST = KB_GROUP_ACTIONS
+
 # Translators: An external braille device has buttons on it that permit the
 # user to create input gestures from the braille device. The braille bindings
 # are what determine the actions Orca will take when the user presses these
@@ -266,8 +354,95 @@ KB_GROUP_DEFAULT = C_("keybindings", "Default")
 KB_GROUP_BRAILLE = _("Braille Bindings")
 
 # Translators: This string is a label for the group of Orca commands which
-# do not currently have an associated key binding.
-KB_GROUP_UNBOUND = _("Unbound")
+# are related to saving and jumping among objects via "bookmarks".
+KB_GROUP_BOOKMARKS = _("Bookmarks")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to caret navigation, such as moving by character, word, and line.
+# These commands are enabled by default for web content and can be optionally
+# toggled on in other applications.
+KB_GROUP_CARET_NAVIGATION = _("Caret navigation")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to the clipboard.
+KB_GROUP_CLIPBOARD = _("Clipboard")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to presenting the date and time.
+KB_GROUP_DATE_AND_TIME = _("Date and time")
+
+# Translators: Orca has a sleep mode which causes Orca to essentially behave as
+# if it were not running for a given application. Some use cases include self-
+# voicing apps with associated commands (e.g. ChromeVox) and VMs. In the former
+# case, the self-voicing app is expected to provide all needed commands as well
+# as speech and braille. In the latter case, we want to ensure that Orca's
+# commands and speech/braille do not interfere with that of the VM and any
+# screen reader being used in that VM. Thus when an application is being used
+# in sleep mode, nearly all Orca commands become unbound/free, and nothing is
+# spoken or brailled. But if the user toggles sleep mode off or switches to
+# another application window, Orca commands, speech, and braille immediately
+# resume working. This string is a label for the group of Orca commands which
+# are related to sleep mode.
+KB_GROUP_SLEEP_MODE = _("Sleep mode")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to presenting the object under the mouse pointer in speech
+# and/or braille. The translation should be consistent with the string
+# used in cmdnames.py.
+KB_GROUP_MOUSE_REVIEW = _("Mouse review")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to object navigation.
+KB_GROUP_OBJECT_NAVIGATION = _("Object navigation")
+
+# Translators: This string is a label for a group of Orca commands which are
+# related to presenting information about the system, such as date, time,
+# battery status, CPU status, etc.
+KB_GROUP_SYSTEM_INFORMATION = _("System information")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to structural navigation, such as moving to the next heading,
+# paragraph, form field, etc. in a given direction.
+KB_GROUP_STRUCTURAL_NAVIGATION = _("Structural navigation")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to table navigation, such as moving to the next cell in a
+# given direction.
+KB_GROUP_TABLE_NAVIGATION = _("Table navigation")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to presenting information about the current location, such as
+# the title, status bar, and default button of the current window; the
+# name, role, and location of the currently-focused object; the selected
+# text in the currently-focused object; etc.
+KB_GROUP_WHERE_AM_I = _("Object details")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to Orca's "flat review" feature. This feature allows the blind
+# user to explore the text in a window in a 2D fashion. That is, Orca treats
+# all the text from all objects in a window (e.g., buttons, labels, etc.) as
+# a sequence of words in a sequence of lines.  The flat review feature allows
+# the user to explore this text by the {previous,next} {line,word,character}.
+# Those commands are all listed under this group label.
+KB_GROUP_FLAT_REVIEW = _("Flat review")
+
+# Translators: This string is a label for the group of Orca commands which
+# are related to Orca's speech and verbosity settings. This group of commands
+# allows on-the-fly configuration of how much (or little) Orca says about a
+# particular object, as well certain aspects of the voice with which things
+# are spoken.
+KB_GROUP_SPEECH_VERBOSITY = _("Speech and verbosity")
+
+# Translators: the 'flat review' feature of Orca allows the blind user to
+# explore the text in a window in a 2D fashion.  That is, Orca treats all
+# the text from all objects in a window (e.g., buttons, labels, etc.) as a
+# sequence of words in a sequence of lines.  The flat review feature allows
+# the user to explore this text by the {previous,next} {line,word,character}.
+# Normally the contents are navigated without leaving the application being
+# reviewed. There is a command which will place the entire contents of the
+# flat review representation into a text view to make it easy to review
+# and copy the text. This string is the title of the window with the text view.
+FLAT_REVIEW_CONTENTS = _("Flat review contents")
 
 # Translators: Modified is a table column header in Orca's preferences dialog.
 # This column contains a checkbox which indicates whether a key binding
@@ -278,6 +453,26 @@ KB_MODIFIED = C_("keybindings", "Modified")
 # Translators: This label refers to the keyboard layout (desktop or laptop).
 KEYBOARD_LAYOUT_DESKTOP = _("_Desktop")
 
+# Translators: Orca has a feature to list all of the notification messages
+# received, similar to the functionality gnome-shell provides when you press
+# Super+M, but it works in all desktop environments. Orca's list is a table
+# with two columns, one column for the text of the notification and one
+# column for the time of the notification. This string is a column header
+# for the text of the notifications.
+NOTIFICATIONS_COLUMN_HEADER = C_("notification presenter", "Notifications")
+
+# Translators: Orca has a feature to list all of the notification messages
+# received, similar to the functionality gnome-shell provides when you press
+# Super+M, but it works in all desktop environments. Orca's list is a table
+# with two columns, one column for the text of the notification and one
+# column for the time of the notification. This string is a column header
+# for the time, which will be relative (e.g. "10 minutes ago") or absolute.
+NOTIFICATIONS_RECEIVED_TIME = C_("notification presenter", "Received")
+
+# Translators: This string is a label for the group of Orca commands which
+# are associated with presenting notifications.
+KB_GROUP_NOTIFICATIONS = _("Notification presenter")
+
 # Translators: Orca's preferences can be configured on a per-application basis,
 # allowing users to customize Orca's behavior, keybindings, etc. to work one
 # way in LibreOffice and another way in a chat application. This string is the
@@ -357,7 +552,7 @@ PROFILE_LOAD_MESSAGE = \
 
 # Translators: Profiles in Orca make it possible for users to quickly switch
 # amongst a group of pre-defined settings (e.g. an 'English' profile for reading
-# text written in English using an English-language speech synthesizer and 
+# text written in English using an English-language speech synthesizer and
 # braille rules, and a similar 'Spanish' profile for reading Spanish text. The
 # following string is the title of a dialog in which users can save a newly-
 # defined profile.
@@ -371,14 +566,6 @@ PROFILE_SAVE_AS_TITLE = _("Save Profile As")
 # name of a new settings profile being saved via the 'Save Profile As' dialog.
 PROFILE_NAME_LABEL = _("_Profile Name:")
 
-# Translators: Profiles in Orca make it possible for users to quickly switch
-# amongst a group of pre-defined settings (e.g. an 'English' profile for reading
-# text written in English using an English-language speech synthesizer and
-# braille rules, and a similar 'Spanish' profile for reading Spanish text.
-# The following is a title in a dialog informing the user that he/she
-# is about to remove a user profile, and action that cannot be undone.
-PROFILE_REMOVE_TITLE = _("Remove User Profile")
-
 # Translators: Profiles in Orca make it possible for users to quickly switch
 # amongst a group of pre-defined settings (e.g. an 'English' profile for reading
 # text written in English using an English-language speech synthesizer and
@@ -483,6 +670,12 @@ SN_HEADER_DESCRIPTION = C_("structural navigation", "Description")
 # contains the text of a heading.
 SN_HEADER_HEADING = C_("structural navigation", "Heading")
 
+# Translators: Orca has a command that presents a list of structural navigation
+# objects in a dialog box so that users can navigate more quickly than they
+# could with native keyboard navigation. This is the title for a column which
+# contains the title associated with an iframe.
+SN_HEADER_IFRAME = C_("structural navigation", "Internal Frame")
+
 # Translators: Orca has a command that presents a list of structural navigation
 # objects in a dialog box so that users can navigate more quickly than they
 # could with native keyboard navigation. This is the title for a column which
@@ -625,6 +818,11 @@ SN_TITLE_FORM_FIELD = C_("structural navigation", "Form Fields")
 # could with native keyboard navigation. This is the title of such a dialog box.
 SN_TITLE_HEADING = C_("structural navigation", "Headings")
 
+# Translators: Orca has a command that presents a list of structural navigation
+# objects in a dialog box so that users can navigate more quickly than they
+# could with native keyboard navigation. This is the title of such a dialog box.
+SN_TITLE_IFRAME = C_("structural navigation", "Internal Frames")
+
 # Translators: Orca has a command that presents a list of structural navigation
 # objects in a dialog box so that users can navigate more quickly than they
 # could with native keyboard navigation. This is the title of such a dialog box.
@@ -734,7 +932,7 @@ SPEECH_VOICE_TYPE_HYPERLINK = C_("VoiceType", "Hyperlink")
 # which is not displayed on the screen as text, but is still being communicated
 # by the system in some visual fashion. For instance, Orca says "misspelled" to
 # indicate the presence of the red squiggly line found under a spelling error;
-# Orca might say "3 of 6" when a user Tabs into a list of six items and the 
+# Orca might say "3 of 6" when a user Tabs into a list of six items and the
 # third item is selected. And so on.
 SPEECH_VOICE_TYPE_SYSTEM = C_("VoiceType", "System")
 
@@ -746,6 +944,10 @@ SPEECH_VOICE_TYPE_UPPERCASE = C_("VoiceType", "Uppercase")
 # system. (http://devel.freebsoft.org/speechd)
 SPEECH_DISPATCHER = _("Speech Dispatcher")
 
+# Translators this label refers to the name of particular speech synthesis
+# system. (https://github.com/eeejay/spiel)
+SPIEL = _("Spiel")
+
 # Translators: This is a label for a group of options related to Orca's behavior
 # when presenting an application's spell check dialog.
 SPELL_CHECK = C_("OptionGroup", "Spell Check")
@@ -827,3 +1029,13 @@ USE_STRUCTURAL_NAVIGATION = _("Enable _structural navigation")
 # Translators: This refers to the amount of information Orca provides about a
 # particular object that receives focus.
 VERBOSITY_LEVEL_BRIEF = _("Brie_f")
+
+def notifications_count(count):
+    """Returns the gui label representing the notifications count."""
+
+    # Translators: Orca has a feature to list all of the notification messages
+    # received, similar to the functionality gnome-shell provides when you press
+    # Super+M, but it works in all desktop environments. This string is the title
+    # of the dialog that contains the list of notification messages. The string
+    # substitution is for the number of messages in the list.
+    return ngettext("%d notification", "%d notifications", count) % count
